@@ -288,7 +288,6 @@ create_plug (BonoboControl *control)
 	g_object_unref (G_OBJECT (plug));
 }
 
-#ifdef HAVE_GTK_MULTIHEAD
 static int
 parse_cookie (const CORBA_char *cookie)
 {
@@ -315,11 +314,11 @@ parse_cookie (const CORBA_char *cookie)
 		case '=':
 			if (!ident || value)
 				goto parse_failed;
-			value = g_string_new ("");
+			value = g_string_new (NULL);
 			break;
 		default:
 			if (!ident)
-				ident = g_string_new ("");
+				ident = g_string_new (NULL);
 			
 			if (value)
 				g_string_append_c (value, *p);
@@ -341,7 +340,6 @@ parse_failed:
 
 	return retval;
 }
-#endif /* HAVE_GTK_MULTIHEAD */
 
 static CORBA_char *
 impl_Bonobo_Control_getWindowId (PortableServer_Servant servant,
@@ -351,17 +349,14 @@ impl_Bonobo_Control_getWindowId (PortableServer_Servant servant,
 	guint32        x11_id;
 	BonoboControl *control = BONOBO_CONTROL (
 		bonobo_object_from_servant (servant));
-#ifdef HAVE_GTK_MULTIHEAD
 	GdkScreen *gdkscreen;
 	int        screen_num;
-#endif
 
 	if (!control->priv->plug)
 		create_plug (control);
 
 	g_assert (control->priv->plug != NULL);
 
-#ifdef HAVE_GTK_MULTIHEAD
 	screen_num = parse_cookie (cookie);
 	if (screen_num != -1)
 		gdkscreen = gdk_display_get_screen (
@@ -370,7 +365,6 @@ impl_Bonobo_Control_getWindowId (PortableServer_Servant servant,
 		gdkscreen = gdk_screen_get_default ();
 
 	gtk_window_set_screen (GTK_WINDOW (control->priv->plug), gdkscreen);
-#endif
 
 	gtk_widget_show (control->priv->plug);
 
@@ -1058,7 +1052,7 @@ bonobo_control_init (BonoboControl *control)
 BONOBO_TYPE_FUNC_FULL (BonoboControl, 
 		       Bonobo_Control,
 		       BONOBO_OBJECT_TYPE,
-		       bonobo_control);
+		       bonobo_control)
 
 /*
  * Varrarg Property get/set simplification wrappers.
@@ -1246,6 +1240,7 @@ bonobo_control_set_transient_for (BonoboControl     *control,
 				  CORBA_Environment *opt_ev)
 {
 	CORBA_char         *id;
+	GdkDisplay         *display;
 	GdkWindow          *win;
 	guint32             x11_id;
 	CORBA_Environment  *ev = 0, tmp_ev;
@@ -1282,7 +1277,8 @@ bonobo_control_set_transient_for (BonoboControl     *control,
 	CORBA_free (id);
 
 	/* FIXME: Special case the local case ? */
-	win = gdk_window_foreign_new (x11_id);
+	display = gtk_widget_get_display (GTK_WIDGET (window));
+	win = gdk_window_foreign_new_for_display (display, x11_id);
 	g_return_if_fail (win != NULL);
 
 	window_set_transient_for_gdk (window, win);
@@ -1450,11 +1446,9 @@ bonobo_control_do_popup_full (BonoboControl       *control,
 
 	g_free (path);
 
-#ifdef HAVE_GTK_MULTIHEAD
 	gtk_menu_set_screen (
 		GTK_MENU (menu),
 		gtk_window_get_screen (GTK_WINDOW (control->priv->plug)));
-#endif /* HAVE_GTK_MULTIHEAD */
 
 	gtk_widget_show (menu);
 
